@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -16,6 +16,8 @@
 import re
 import grok
 
+from z3c.flashmessage.interfaces import IMessageReceiver
+from zope import component
 
 LINK_PATTERN = re.compile('\[\[(.*?)\]\]')
 find_wiki_links = LINK_PATTERN.findall
@@ -58,17 +60,18 @@ class Edit(grok.View):
         self.flash('Saved.')
         self.redirect(self.url(self.context))
 
+class Messages(grok.View):
+    @property
+    def messages(self):
+        receiver = component.getUtility(IMessageReceiver)
+        return receiver.receive()
 
 class WikiLayer(grok.IRESTLayer):
-    pass
+    # This skin will be visible as http://localhost:8080/++rest++wiki/...
+    grok.restskin('wiki')
 
 class PageRest(grok.REST):
     grok.layer(WikiLayer)
     
     def GET(self):
         return "Hello world"
-    
-class WikiProtocol(grok.RESTProtocol):
-    grok.layer(WikiLayer)
-    grok.name('wiki')
-
